#!/usr/bin/env python3

# rcb.gov.pl, twitter.com/RCB_PL

import datetime
import random

from .tlib import c, b, f, w, int_to_roman, next_isoweekday, d

_VOIVODESHIP = c(
    'dolnośląskim',
    'kujawsko-pomorskim',
    'lubelskim',
    'lubuskim',
    'łódzkim',
    'małopolskim',
    'mazowieckim',
    'opolskim',
    'podkarpackim',
    'podlaskim',
    'pomorskim',
    'śląskim',
    'świętokrzyskim',
    'warmińsko-mazurskim',
    'wielkopolskim',
    'zachodniopomorskim',
)

TEMPLATE_STANDARD = [
    'Uwaga! Dziś ',
    c('wieczorem', 'w nocy', 'wieczorem i w nocy', 'po południu i w nocy'),
    ' (', d, ') ',
    c(
        'bardzo silny wiatr',
        'silny wiatr, burze i grad',
        'ulewny deszcz i burze z gradem',
        'ulewny deszcz i burze z silnym wiatrem',
        'silny wiatr i burze z gradem',
        'bardzo silny wiatr i burze z gradem',
    ), '.',

    b(0.95,
        [
            c(
                ' Unikaj otwartych przestrzeni.',
                ' Zabezpiecz rzeczy, które może porwać wiatr.',
                c(
                    ' Zostań w domu, jeśli możesz.',
                    ' Jeśli możesz, zostań w domu.',
                    ' Jeśli możesz - zostań w domu.',
                ),
                ' Nie zbliżaj się do rzek.',
                ' Nie chowaj się pod drzewami.',
                ' Przygotuj się na podtopienia.',
                ' Stosuj się do poleceń służb.',
                ' W trakcie burzy znajdź bezpieczne schronienie.',
                ' Możliwe przerwy w dostawie prądu.',
                ' Nie biegaj z siekerą po podwórku, bo możesz się skaleczyć.',
            min=0, max=4),
        ],
        c(' Nie zesraj się.', ' Kryj ryj!'),
    ),
]

TEMPLATE_FLOOD = [
    'Uwaga! Fala wezbraniowa na ',
    b(0.8,
        ['Wiśle w woj. ', c('śląskim', 'małopolskim', 'świętokrzyskim',
            'podkarpackim', 'lubelskim', 'mazowieckim', 'kujawsko-pomorskim',
            'pomorskim'),
        ],
        'Odrze w Wodzisławiu',
    ),
    ' - kulminacja ', c(
        'w niedzielę i poniedziałek',
        'w poniedziałek i wtorek',
        'we wtorek i środę',
        'w środę i czwartek',
        'w czwartek i piątek',
        'w piątek i sobotę',
        'w sobotę i niedzielę',
    ), '.'
]

TEMPLATE_SHIT = [
    'Uwaga! Główny Inspektor Sanitarny apeluje: w Wiśle, od Warszawy w stronę ',
    'Gdańska, unikaj kąpieli i sportów wodnych. Nie używaj do mycia wody ',
    'z rzeki.'
]

TEMPLATE_ZONE = [
    'Uwaga! Cała Polska w ',
    c(
        'czerwonej',
        'żółtej',
        'zielonej',
        'niebieskiej',
        'różowej',
        'czarnej',
        'brunatnej',
    ),
    ' strefie. Pobierz aplikację ',
    c(
        'STOP COVID',
        'Kwarantannta Domowa',
        'ProteGO Safe',
        'CBA W TWOIM ŁÓŻKU',
        '***** ***',
    ),
    '. Dowiesz się o kontakcie z koronawirusem. #gramyozdrowie #gralempolakamiiumarli',
]

# II tura wyborów prezydenckich w niedzielę {{ data }}. Osoby 60+, kobiety
# w ciąży oraz osoby niepełnosprawne będą mogły głosować w komisjach wyborczych
# bez kolejki.
TEMPLATE_PRESIDENTIAL_ELECTION = [
    (lambda: int_to_roman(random.randrange(100))),
    ' tura wyborów prezydenckich w niedzielę ',
    d(date=next_isoweekday(0)),
    '. Osoby 60+, ',
    c(
        'kobiety w ciąży, ',
        'emeryci, ',
        'renciści, ',
        'honorowi dawcy krwi, ',
        'Stierlitz i Kloss, ',
        'Bohaterowie Związku Radzieckiego, ',
        'obywatele San Escobar, ',
        'wyborcy PiS, ',
        'słuchacze Radia Maryja, ',
        'fani polskiego rapu, ',
        'fani Zenka Martyniuka, ',
    min=2, max=5),
    'oraz osoby niepełnosprawne będą mogły głosować w komisjach wyborczych ',
    'bez kolejki.'
]

TEMPLATE_NIGHT = [
    'Uwaga! Dziś w nocy (', d, ') będzie ciemno.',
]

TEMPLATE_SHITPOST = [
    'Uwaga! Dziś (', d, ') silne gównoburze na terenie całego Internetu. ',
    'Chroń oczy i uszy. ',
    'Jeśli widzisz głupie posty, zachowuj bezpieczną odległość od klawiatury.',
]


TEMPLATE_ITHLINNESPEATH = [
    # Zaprawdę powiadam wam, oto nadchodzi wiek miecza i topora, wiek wilczej
    # zamieci. Nadchodzi Czas Białego Zimna i Białego Światła, Czas Szaleństwa
    # i Czas Pogardy, Tedd Deireádh, Czas Końca. Świat umrze wśród mrozu,
    # a odrodzi się wraz z nowym słońcem. Odrodzi się ze Starszej Krwi, z Hen
    # Ichaer, z zasianego ziarna. Ziarna, które nie wykiełkuje, lecz wybuchnie
    # płomieniem.
    # 
    # Ess'tuath esse! Tak będzie! Wypatrujcie znaków! Jakie to będą znaki,
    # rzeknę wam - wprzód spłynie ziemia Aen Seidhe, Krwią Elfów...
    # 
    # -- Andrzej Sapkowski, „Krew elfów” (1994)

    'Zaprawdę powiadam wam, oto nadchodzi wiek miecza i topora, wiek wilczej ',
    'zamieci. Nadchodzi Czas Białego Zimna i Białego Światła, Czas Szaleństwa ',
    'i Czas Pogardy, Tedd Deireádh, Czas Końca.',

    c(
        ' Kiedy nadejdzie Białe Zimno, nie jedz Żółtego Śniegu.',  # Wiedźmin 3
        ' W trakcie burzy znajdź bezpieczne schronienie.',
        ' Możliwe przerwy w dostawie prądu.',
        ' Stosuj się do poleceń służb.',
    min=1, max=2),
]


TEMPLATE_KONOPIELKA = [
    # O, do czego idzie! Krowy bedo sie źrebili, kobyły cielili, owieczki
    # prosili! Chłop z chłopem spać bedzie, baba z babo, wilki latać, bociany
    # pływać, słońce wzejdzie na zachodzie, zajdzie na wschodzie! [...]
    # A w miastach, co w miastach sie wyprawia! W dzień śpio, w nocy pracujo,
    # w piątki nie poszczo, niedzielow nie świętujo! Sodomagomora!
    #
    # Żony mężow rzucajo! W Boga nie wierzo. Z ludziow mydło sie robi! Gospody,
    # kurestwo, sodomagomora!
    #
    # -- Edward Redliński, „Konopielka” (1973)

    'O, do czego idzie! Krowy bedo sie źrebili, kobyły cielili, owieczki ',
    'prosili! Chłop z chłopem spać bedzie, baba z babo, wilki latać, bociany ',
    'pływać, słońce wzejdzie na zachodzie, zajdzie na wschodzie! ',

    c([
        'A w miastach, co w miastach sie wyprawia! W dzień śpio, w nocy ',
        'pracujo, w piątki nie poszczo, niedzielow nie świętujo! ',
        'Sodomagomora! ',
    ], [
        'Żony mężow rzucajo! W Boga nie wierzo. Z ludziow mydło sie robi! ',
        'Gospody, kurestwo, sodomagomora! ',
    ], min=0, max=1)
]


TEMPLATE_STACHURSKY = [
    'Potężna wichura, łamiąc duże drzewa, trzciną zaledwie tylko kołysze. '
    'Uważaj, uważaj, uważaj, uważaj.'
]


TEMPLATE_DVBT2 = [
    d, ' w woj. ', _VOIVODESHIP, ' nastąpi zmiana standardu nadawania ',
    'TV naziemnej. Sprawdź, czy Twój telewizor działa w nowym systemie.',
]


TEMPLATE_WYSY_PIS_KO = [
    'Uwaga! W m. Przylep (', d, ') palą się substancje niebezpieczne. Zachowaj ',
    'ostrożność, nie zbliżaj się do miejsca pożaru. Jeśli możesz, zostań ',
    'w domu, zamknij okna. #WysyPiSko #ZapachPiS',
]


TEMPLATE = w(
    (20, TEMPLATE_STANDARD),
    ( 2, TEMPLATE_ZONE),
    ( 2, TEMPLATE_NIGHT),
    ( 2, TEMPLATE_SHITPOST),
    ( 2, TEMPLATE_PRESIDENTIAL_ELECTION),
    ( 2, c(TEMPLATE_FLOOD, TEMPLATE_SHIT)),
    ( 2, TEMPLATE_STACHURSKY),
    ( 2, TEMPLATE_DVBT2),
    ( 2, TEMPLATE_WYSY_PIS_KO),
    ( 1, c(TEMPLATE_ITHLINNESPEATH, TEMPLATE_KONOPIELKA)),
)
